class Admin::AnnouncementsController < ApplicationController
  
  before_filter :require_entry_name, :only => [:index, :new]
  
  layout "admin"
  
  def index
    @announcements = Announcement.find(:all, :conditions => { :entry_name => params[:entry_name] })

    respond_to do |format|
      format.html
      format.xml  { render :xml => @announcements }
    end
  end

  def new
    @announcement = Announcement.new
    @announcement.entry_name = params[:entry_name]
    
    respond_to do |format|
      format.htm
      format.xml  { render :xml => @announcement }
    end
  end

  def edit
    @announcement = Announcement.find(params[:id])
  end

  def create
    @announcement = Announcement.new(params[:announcement])
    
    respond_to do |format|
      if @announcement.save
        flash[:notice] = 'Announcement was successfully created.'
        format.html { redirect_to admin_announcements_path }
        format.xml  { render :xml => @announcement, :status => :created, :location => @announcement }
      else
        format.html { render :action => "new" }
        format.xml  { render :xml => @announcement.errors, :status => :unprocessable_entity }
      end
    end
  end

  def update
    @announcement = Announcement.find(params[:id])

    respond_to do |format|
      if @announcement.update_attributes(params[:announcement])
        flash[:notice] = 'Announcement was successfully updated.'
        format.html { redirect_to admin_announcements_path }
        format.xml  { head :ok }
      else
        format.html { render :action => "edit" }
        format.xml  { render :xml => @announcement.errors, :status => :unprocessable_entity }
      end
    end
  end

  def destroy
    @announcement = Announcement.find(params[:id])
    @announcement.destroy

    respond_to do |format|
      format.html { redirect_to admin_announcements_path }
      format.xml  { head :ok }
    end
  end
end
